# Epidemic forecasting from multiple data sources

This repository generates epidemic forecasts from multiple data sources.

**IMPORTANT:** note that the original data files cannot be provided, as the
authors do not have permission to distribute these data.

## License

The code is distributed under the terms of the BSD 3-Clause license (see
`LICENSE`), and the documentation is distributed under the terms of the
[Creative Commons BY-SA 4.0
license](http://creativecommons.org/licenses/by-sa/4.0/).

## Dependencies

This package requires
[pypfilt](http://bitbucket.org/robmoss/particle-filter-for-python/) == 0.1.2,
[epifx](http://bitbucket.org/robmoss/epidemic-forecasting-for-python) == 0.1.10,
[h5py](http://www.h5py.org/) >= 2.2,
[NumPy](http://www.numpy.org/) >= 1.8,
[SciPy](http://www.scipy.org/) >= 0.11, and
[Six](https://pythonhosted.org/six/) >= 1.7.

## Installation

To generate forecasts without affecting your Python installation, create a
[virtual environment](http://docs.python-guide.org/en/latest/dev/virtualenvs/)
and activate it:

    virtualenv epifx
    source epifx/bin/activate

Then install the required packages that are available on
[PyPI](http://pypi.python.org/):

    # Install NumPy before SciPy.
    pip install 'numpy==1.9.2' 'six==1.8'
    pip install 'scipy==0.15.1'
    # Install Cython before h5py.
    pip install 'Cython>=0.17'
    pip install 'h5py==2.4'

Finally, install the required versions of ``pypfilt`` and ``epifx``:

    git clone -b 0.1.2 http://bitbucket.org/robmoss/particle-filter-for-python/
    cd particle-filter-for-python
    python setup.py install

    cd ..

    git clone -b 0.1.10 http://bitbucket.org/robmoss/epidemic-forecasting-for-python
    cd epidemic-forecasting-for-python
    python setup.py install

## Usage

To run forecasting simulations, see the output of:

    ./run-forecast.py --help

To generate forecasts using replacement data files, run the following command:

    ./run-forecast.py --gpss-file=gpss.csv --mmds-file=mmds.csv --vdh-file=vdh.csv

You will need to **provide** or **generate** these data files.

The AUC scores for each observation model for each influenza season can then
be calculated by running the following command:

    ./calc-auc.py /path/to/output/files/

Note that the simulation outputs are stochastic in nature, and have been
observed to differ depending on the installed versions of the NumPy and SciPy
packages, due to changes in the random number generator implementation, even
when using identical seeds for the pseudo-random number generators.
